@@ -66,13 +66,13 @@ def search_searxng_news(keywords: str, category: str="news", **kwargs):
 
 TOOL_SCHEMA = {
     "name": "search_searxng_news",
-    "description": "Perform online searches to obtain the latest and most up-to-date, real-time information",
+    "description": "Perform online searches up-to-date and real-time news information",
     "parameters": {
         "type": "object",
         "properties": {
             "keywords": {
                 "type": "string",
-                "description": "Keywords for online searches",
+                "description": "Keywords for online news searches",
             },
         },
         "required": ["keywords"],
